/*
- 파일명: my-toc-admin.js
- 위치: /my-toc-plugin/assets/js/
- 기능: TOC 플러그인의 관리자 페이지 자바스크립트
- 작성일: 2025-03-23
*/

// ===================================
// 관리자 페이지 스크립트
// ===================================
jQuery(document).ready(function($) {
    
    console.log('TOC Admin JS loaded'); // 디버깅용 로그
    
    // ===================================
    // 사용자 정의 색상 토글
    // ===================================
    /* 테마 변경 시 사용자 정의 색상 표시/숨김 */
    function toggleCustomColors() {
        console.log('Toggling custom colors'); // 디버깅용 로그
        var theme = $('#my-toc-theme').val();
        
        if (theme === 'custom') {
            $('#my-toc-custom-colors').show();
        } else {
            $('#my-toc-custom-colors').hide();
        }
    }
    
    // 페이지 로드 시 초기 상태 설정
    toggleCustomColors();
    
    // 테마 변경 이벤트 리스너
	$('#my-toc-theme').on('change', function() {
		console.log('Theme changed to: ' + $(this).val()); // 디버깅 로그 추가
		toggleCustomColors();
		// 약간의 딜레이를 주어 DOM이 업데이트될 시간을 주기
		setTimeout(function() {
			updatePreview();
		}, 50);
	});
    
    // ===================================
    // 붙박이 위치 토글
    // ===================================
    /* 붙박이 기능 변경 시 위치 옵션 표시/숨김 */
    function toggleStickyPosition() {
        var sticky = $('#my-toc-sticky').val();
        
        if (sticky === 'on') {
            $('#my-toc-sticky-position').closest('tr').show();
        } else {
            $('#my-toc-sticky-position').closest('tr').hide();
        }
    }
    
    // 페이지 로드 시 초기 상태 설정
    toggleStickyPosition();
    
    // 붙박이 기능 변경 이벤트 리스너
    $('#my-toc-sticky').on('change', function() {
        toggleStickyPosition();
    });
    
    // ===================================
    // 색상 선택기 초기화
    // ===================================
    /* 색상 선택기에 부트스트랩 스타일 적용 */
    $('.my-toc-color-field input[type="color"]').each(function() {
        $(this).addClass('form-control');
    });
    
    // ===================================
    // 기호 버튼 기능
    // ===================================
    /* 기호 버튼 클릭 시 입력란에 기호 추가 */
    $('.symbol-btn').on('click', function() {
        var symbol = $(this).data('symbol');
        var target = $(this).data('target');
        
        if (target === 'h2') {
            $('#my_toc_options_h2_prefix').val(symbol);
        } else if (target === 'h3') {
            $('#my_toc_options_h3_prefix').val(symbol);
        }
    });
    
   // ===================================
// 미리보기 기능
// ===================================
// 미리보기 업데이트
function updatePreview() {
    console.log('Updating preview started'); // 디버깅용 로그
    
    // DOM에 미리보기 요소가 존재하는지 확인
    if ($('#my-toc-live-preview .my-toc').length === 0) {
        console.log('Preview element not found!');
        return;
    }
    
    // 현재 설정 가져오기
    var theme = $('#my-toc-theme').val() || 'gray';
    var headerLabel = $('input[name="my_toc_options[header_label]"]').val() || '목차';
    var h2Prefix = $('input[name="my_toc_options[h2_prefix]"]').val() || '';
    var h3Prefix = $('input[name="my_toc_options[h3_prefix]"]').val() || '';
    var initialView = $('select[name="my_toc_options[initial_view]"]').val() || 'show';
    
    var $preview = $('#my-toc-live-preview .my-toc');
    
    // 테마 클래스 업데이트
    $preview.removeClass('my-toc-theme-gray my-toc-theme-blue my-toc-theme-white my-toc-theme-warm my-toc-theme-custom');
    $preview.addClass('my-toc-theme-' + theme);
    
    // 테마에 따른 스타일 직접 적용 (클래스만으로 적용이 안 될 경우)
    switch(theme) {
        case 'gray':
            $preview.css({
                'background-color': '#f9f9f9',
                'border-color': '#ddd'
            });
            break;
        case 'blue':
            $preview.css({
                'background-color': '#e6f6ff',
                'border-color': '#a8d8ff'
            });
            break;
        case 'white':
            $preview.css({
                'background-color': '#ffffff',
                'border-color': '#eeeeee'
            });
            break;
        case 'warm':
            $preview.css({
                'background-color': '#fff5e6',
                'border-color': '#ffcc80'
            });
            break;
        // custom 테마는 아래 별도 코드에서 처리
    }
    
    // 헤더 라벨 업데이트
    $preview.find('.my-toc-title').text(headerLabel);
    
    // 초기 보기 상태 업데이트
    if (initialView === 'hide') {
        $preview.addClass('my-toc-collapsed');
        $preview.find('.my-toc-content').addClass('my-toc-content-hidden');
        $preview.find('.my-toc-toggle i').removeClass('bi-dash').addClass('bi-plus');
    } else {
        $preview.removeClass('my-toc-collapsed');
        $preview.find('.my-toc-content').removeClass('my-toc-content-hidden');
        $preview.find('.my-toc-toggle i').removeClass('bi-plus').addClass('bi-dash');
    }
    
    // 접두사 업데이트
    $preview.find('.my-toc-level-2 .my-toc-prefix').remove();
    $preview.find('.my-toc-level-3 .my-toc-prefix').remove();
    
    if (h2Prefix) {
        $preview.find('.my-toc-level-2 > a').prepend('<span class="my-toc-prefix">' + h2Prefix + '</span>');
    }
    
    if (h3Prefix) {
        $preview.find('.my-toc-level-3 > a').prepend('<span class="my-toc-prefix">' + h3Prefix + '</span>');
    }
    
    // 사용자 정의 색상 적용
    if (theme === 'custom') {
        var backgroundColor = $('input[name="my_toc_options[custom_colors][background]"]').val();
        var borderColor = $('input[name="my_toc_options[custom_colors][border]"]').val();
        var titleColor = $('input[name="my_toc_options[custom_colors][title]"]').val();
        var linkColor = $('input[name="my_toc_options[custom_colors][link]"]').val();
        var hoverColor = $('input[name="my_toc_options[custom_colors][hover]"]').val();
        
        $preview.css({
            'background-color': backgroundColor,
            'border-color': borderColor
        });
        
        $preview.find('.my-toc-title').css('color', titleColor);
        $preview.find('.my-toc-list a').css('color', linkColor);
        
        // 데이터 속성 업데이트
        $preview.attr('data-link-color', linkColor);
        $preview.attr('data-hover-color', hoverColor);
        
        // 호버 스타일을 위한 CSS 규칙 추가/업데이트
        var styleId = 'my-toc-custom-preview-style';
        var $style = $('#' + styleId);
        
        if ($style.length === 0) {
            $style = $('<style id="' + styleId + '"></style>').appendTo('head');
        }
        
        $style.html('#my-toc-live-preview .my-toc-theme-custom .my-toc-list a:hover { color: ' + hoverColor + ' !important; }');
    } else {
        // 기본 테마의 경우 인라인 스타일 제거 (테마 클래스가 적용되도록)
        // 위의 switch문에서 적용한 스타일은 유지
        $preview.find('.my-toc-title').attr('style', '');
        $preview.find('.my-toc-list a').attr('style', '');
        
        // 호버 스타일 제거
        $('#my-toc-custom-preview-style').remove();
    }
    
    console.log('Preview updated'); // 디버깅용 로그
}





/* 
 * 설정 변경 시 미리보기 업데이트 - 서브섹션 
 */
// 초기 미리보기 설정
setTimeout(updatePreview, 100);

// 모든 설정 입력 필드의 변경 감지
$('input[name^="my_toc_options"], select[name^="my_toc_options"]').on('change keyup input', function() {
    console.log('Settings changed: ' + $(this).attr('name')); // 디버깅 로그 추가
    updatePreview();
});


// 미리보기 토글 기능
$('#my-toc-live-preview .my-toc-toggle').on('click', function() {
    var $content = $('#my-toc-live-preview .my-toc-content');
    var $icon = $(this).find('i');
    
    $content.toggleClass('my-toc-content-hidden');
    
    if ($content.hasClass('my-toc-content-hidden')) {
        $icon.removeClass('bi-dash').addClass('bi-plus');
    } else {
        $icon.removeClass('bi-plus').addClass('bi-dash');
    }
}); 


}); // 이 부분이 누락됨 - document.ready 함수 닫기