<?php
/*
- 파일명: my-toc-plugin.php
- 위치: /my-toc-plugin/
- 기능: TOC 플러그인의 메인 파일. 플러그인 초기화 및 필요한 파일 포함.
- 작성일: 2025-03-23
*/

/*
Plugin Name: My TOC Plugin
Plugin URI: https://url.kr/p/wp-plugin/my-toc-plugin/
Description: 워드프레스 블로그에서 H2, H3, H4 태그를 자동으로 인식하여 목차(Table of Contents)를 생성하는 플러그인입니다.
Version: 1.0.0
Author: 호텔천사
Author URI: https://webworks.co.kr
Text Domain: my-toc-plugin
Domain Path: /languages
*/

// 직접 접근 방지
if (!defined('ABSPATH')) {
    exit;
}

// ===================================
// 상수 정의
// ===================================
define('MY_TOC_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('MY_TOC_PLUGIN_URL', plugin_dir_url(__FILE__));
define('MY_TOC_PLUGIN_VERSION', '1.0.0');

// ===================================
// 플러그인 초기화
// ===================================
/* 클래스 파일 포함 */
require_once MY_TOC_PLUGIN_DIR . 'includes/class-my-toc-admin.php';
require_once MY_TOC_PLUGIN_DIR . 'includes/class-my-toc-frontend.php';

/* 플러그인 활성화/비활성화 훅 */
register_activation_hook(__FILE__, 'my_toc_plugin_activate');
register_deactivation_hook(__FILE__, 'my_toc_plugin_deactivate');

/**
 * 플러그인 활성화 시 실행되는 함수
 *
 * @return void
 */
function my_toc_plugin_activate() {
    // 기본 옵션 설정
    $default_options = array(
        'position' => 'before', // 첫 머리글 앞
        'min_headers' => 2, // H2 태그가 2개 이상일 때만 표시
        'header_label' => '목차', // 기본 헤더 라벨
        'initial_view' => 'show', // 초기에 표시
        'theme' => 'gray', // 기본 테마
        'custom_colors' => array(
            'background' => '#f9f9f9',
            'border' => '#ddd',
            'title' => '#333',
            'link' => '#0073aa',
            'hover' => '#00a0d2',
            'visited' => '#800080'
        ),
        'sticky' => 'off', // 붙박이 기능 끄기
        'sticky_position' => 'right-top', // 붙박이 위치
    );
    
    // 옵션이 없는 경우에만 추가
    if (!get_option('my_toc_options')) {
        add_option('my_toc_options', $default_options);
    }
    
    // 플러그인 활성화 시 리라이트 규칙 초기화
    flush_rewrite_rules();
}

/**
 * 플러그인 비활성화 시 실행되는 함수
 *
 * @return void
 */
function my_toc_plugin_deactivate() {
    flush_rewrite_rules();
}

/**
 * 플러그인 초기화 함수
 *
 * @return void
 */
function my_toc_plugin_init() {
    // 관리자 클래스 초기화
    $my_toc_admin = new My_TOC_Admin();
    $my_toc_admin->init();
    
    // 프론트엔드 클래스 초기화
    $my_toc_frontend = new My_TOC_Frontend();
    $my_toc_frontend->init();
}

// 플러그인 초기화 실행
add_action('plugins_loaded', 'my_toc_plugin_init');